@@ -17,15 +17,18 @@ utils::globalVariables(c(
   "assess_object",
   "coef",
   "contains",
+  "data", 
   "estimate",
   "estimate.x",
   "estimate.y",
+  ".extracts",
   "id",
   "idx",
   "lp",
   "mem",
   "member",
   "members",
+  "mixture",
   "model",
   "model_type",
   "n",
